@@ -17,8 +17,8 @@ function main(content, node) {
     // convert QR download links into the actual QR codes
     var res = node.result;
     for (var i = 0; i < res.length; ++i) {
-        var ticketToken = res[i].reservedTicket.ticketToken;
-        res[i].reservedTicket.ticketToken = ticketToken.replace(/^https?:\/\/api\.(?:flixbus|meinfernbus)\..{2,3}\/qrcode\/(..)\//, "qrCode:https://shop.flixbus.$1/pdfqr/");
+        res[i].reservedTicket.ticketToken = res[i].reservedTicket.ticketToken.replace(/^https?:\/\/api\.(?:flixbus|meinfernbus)\..{2,3}\/qrcode\/(..)\//, "qrCode:https://shop.flixbus.$1/pdfqr/");
+        res[i].reservedTicket.ticketToken = res[i].reservedTicket.ticketToken.replace(/^(https?:\/\/.*$/, "qrCode:$1");
 
         // their schema.org annotations also claim train trips are bus trips, fix that
         res[i] = fixTransportMode(res[i]);
@@ -56,14 +56,14 @@ function parsePdfTicket(pdf, node, triggerNode)
     const date = text.match(/^\S+,? (\d+\.? \S+) (\d{4})\n/);
 
     const timeColumn = page.textInRect(0.0, 0.1, 0.125, 0.5);
-    const stationColumn = page.textInRect(0.125, 0.1, 0.5, 0.5);
+    const stationColumn = page.textInRect(0.125, 0.1, 0.5, 0.55);
 
     let idxTime = 0;
     let idxStations = 0;
     let reservations = [];
     while (true) {
         const times = timeColumn.substr(idxTime).match(/(\d\d:\d\d)\n([^:]*?\n)?([^:]*?\n)?(\d\d:\d\d)/);
-        const stations = stationColumn.substr(idxStations).match(/(.*)\n[ ]+(.*)(?:\n|,\n  +(.*)\n)(?:.*\n(?:.*\n)*)?.*(?:Bus|Autobus|Zug) +(.*)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung) (.*)\n(.*)\n(?:[ ]+(.*?)(?:\n|,\n +(.*)\n))?/);
+        const stations = stationColumn.substr(idxStations).match(/(.*)\n[ ]+(.*)(?:\n|,\n  +(.*)\n)(?:.*(?:NOTE:|Wagennummerierung).(?:.*\n)+)?.*(?:Bus|Autobus|Zug|Strecke) +(.*)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung) (.*)\n(?:.*(?:Operated|Betrieben).*\n)?(.*)\n(?:[ ]+(.*?)(?:\n|,\n +(.*)\n))?/);
         if (!times || !stations) {
             break;
         }
@@ -96,7 +96,7 @@ function parsePdfTicket(pdf, node, triggerNode)
     let personalizedReservations = [];
     while (true) {
         const pas = rightSide.substr(idx).match(/(\S+.*\S)  +(?:(\d+) · )?(\d+[A-Z])\n/);
-        if (!pas) {
+        if (!pas || pas[0].match(/\d+[A-Z]\s.*\s\d+[A-Z]/)) { // multiple seats in the same row not supported yet
             break;
         }
         idx += pas.index + pas[0].length;
